@@ -489,6 +489,13 @@ void wikitotextinline(TCXSTR *rbuf, const char *line){
         tcxstrcat2(rbuf, "##");
         tcfree(field);
         line = pv + 2;
+      } else if(tcstrfwm(line, "[$") && (pv = strstr(line + 2, "$]")) != NULL){
+        char *field = tcmemdup(line + 2, pv - line - 2);
+        tcxstrcat2(rbuf, "$$");
+        wikitotextinline(rbuf, field);
+        tcxstrcat2(rbuf, "$$");
+        tcfree(field);
+        line = pv + 2;
       } else if(tcstrfwm(line, "[=") && (pv = strstr(line + 2, "=]")) != NULL){
         char *field = tcmemdup(line + 2, pv - line - 2);
         tcxstrprintf(rbuf, "%s", field);
@@ -986,6 +993,13 @@ void wikitohtmlinline(TCXSTR *rbuf, const char *line, const char *buri, const ch
         tcxstrcat2(rbuf, "</code>");
         tcfree(field);
         line = pv + 2;
+      } else if(tcstrfwm(line, "[$") && (pv = strstr(line + 2, "$]")) != NULL){
+        char *field = tcmemdup(line + 2, pv - line - 2);
+        tcxstrcat2(rbuf, "<var>");
+        wikitohtmlinline(rbuf, field, buri, duri);
+        tcxstrcat2(rbuf, "</var>");
+        tcfree(field);
+        line = pv + 2;
       } else if(tcstrfwm(line, "[=") && (pv = strstr(line + 2, "=]")) != NULL){
         char *field = tcmemdup(line + 2, pv - line - 2);
         tcxstrprintf(rbuf, "%@", field);
