@@ -98,6 +98,16 @@ int main(int argc, char **argv){
   }
   char *barepath = tcregexreplace(g_scriptpath, "\\.[a-zA-Z0-9]*$", "");
   char *tmplpath = tcsprintf("%s.tmpl", barepath);
+  const char *rp = getenv("REQUEST_URI");
+  char *scriptnamebuf = NULL;
+  if(rp && *rp == '/'){
+    scriptnamebuf = strdup(rp);
+    char *pv = strchr(scriptnamebuf, '#');
+    if(pv) *pv = '\0';
+    pv = strchr(scriptnamebuf, '?');
+    if(pv) *pv = '\0';
+    if(*scriptnamebuf != '\0') g_scriptname = scriptnamebuf;
+  }
   g_tmpl = tctmplnew();
   if(tctmplload2(g_tmpl, tmplpath)){
     g_database = tctmplconf(g_tmpl, "database");
@@ -168,6 +178,7 @@ int main(int argc, char **argv){
   } else {
     showerror(500, "The template file is missing.");
   }
+  tcfree(scriptnamebuf);
   tcfree(docrootbuf);
   tctmpldel(g_tmpl);
   tcfree(tmplpath);
@@ -1276,7 +1287,7 @@ static void dosession(TCMPOOL *mpool){
   if(authcookie){
     printf("Set-Cookie: auth=%s;", authcookie);
     if(g_sessionlife > 0) printf(" max-age=%d;", g_sessionlife);
-    printf(" path=%s\r\n", g_scriptname);
+    printf("\r\n");
   }
   printf("\r\n");
   fwrite(tmplstr, 1, strlen(tmplstr), stdout);
